#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @File  : EmebddingModel.py
# @Author: Richard Chiming Xu
# @Date  : 2024/6/17
# @Desc  : 向量化模型

import requests
from datetime import datetime
from wsgiref.handlers import format_date_time
from time import mktime
import hashlib
import base64
import hmac
from urllib.parse import urlencode
import json
import numpy as np
from loguru import logger

from dwspark.config import Config


class EmbeddingModel(object):
    def __init__(self, config: Config, model_url: str = 'https://emb-cn-huabei-1.xf-yun.com/'):
        '''
        图片理解（https://www.xfyun.cn/doc/spark/ImageUnderstanding.html）
        :param config: 项目配置文件
        :param model_url: 模型地址
        '''
        # 讯飞的api配置
        self.appid = config.XF_APPID
        self.apikey = config.XF_APIKEY
        self.apisecret = config.XF_APISECRET
        # url地址
        self.model_url = model_url
        self.host, self.path, self.schema = self.__parse_url(model_url)

    def get_embedding(self, text: str, style: str = 'query') -> np.array:
        # 准备请求体
        req_body = {
            "header": {"app_id": self.appid, "status": 3},
            "parameter": {"emb": {"domain": style, "feature": {"encoding": "utf8"}}},
            "payload": {"messages": {"text": base64.b64encode(json.dumps({"messages": [{"content": text, "role": "user"}]}).encode('utf-8')).decode()}}
        }
        # 生成url
        url = self.__create_url("POST")
        # 调用接口
        resp_data = requests.post(url, json=req_body, headers={'content-type': "application/json"}).json()
        # 提取输出
        code = resp_data['header']['code']
        if code != 0:
            raise Exception(f'请求错误: {code}, {resp_data}')
        else:
            sid = resp_data['header']['sid']
            text_base = resp_data["payload"]["feature"]["text"]
            # 使用base64.b64decode()函数将text_base解码为字节串text_data
            text_data = base64.b64decode(text_base)
            # 创建一个np.float32类型的数据类型对象dt，表示32位浮点数。
            dt = np.dtype(np.float32)
            # 使用newbyteorder()方法将dt的字节序设置为小端（"<"）
            dt = dt.newbyteorder("<")
            # 使用np.frombuffer()函数将text_data转换为浮点数数组text，数据类型为dt。
            text = np.frombuffer(text_data, dtype=dt)
            # # 打印向量维度
            return text

    def __create_url(self, method="GET"):
        now = datetime.now()
        date = format_date_time(mktime(now.timetuple()))
        # date = "Thu, 12 Dec 2019 01:57:27 GMT"
        signature_origin = "host: {}\ndate: {}\n{} {} HTTP/1.1".format(self.host, date, method, self.path)
        signature_sha = hmac.new(self.apisecret.encode('utf-8'), signature_origin.encode('utf-8'),
                                 digestmod=hashlib.sha256).digest()
        signature_sha = base64.b64encode(signature_sha).decode(encoding='utf-8')
        authorization_origin = "api_key=\"%s\", algorithm=\"%s\", headers=\"%s\", signature=\"%s\"" % (
            self.apikey, "hmac-sha256", "host date request-line", signature_sha)
        authorization = base64.b64encode(authorization_origin.encode('utf-8')).decode(encoding='utf-8')
        values = {
            "host": self.host,
            "date": date,
            "authorization": authorization
        }

        return self.model_url + "?" + urlencode(values)

    def __parse_url(self, requset_url):
        stidx = requset_url.index("://")
        host = requset_url[stidx + 3:]
        schema = requset_url[:stidx + 3]
        edidx = host.index("/")
        if edidx <= 0:
            raise Exception("错误的请求地址:" + requset_url)
        path = host[edidx:]
        host = host[:edidx]
        return host, path, schema


if __name__ == '__main__':
    config = Config()
    em = EmebddingModel(config)
    vector = em.get_embedding("我们是datawhale")
    logger.info(vector)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @File  : ChatModel.py
# @Author: Richard Chiming Xu
# @Date  : 2024/6/17
# @Desc  : 认知大模型，API文档：https://www.xfyun.cn/doc/spark/Web.html
from typing import List, Iterable

from sparkai.llm.llm import ChatSparkLLM
from sparkai.core.messages import ChatMessage
from dwspark.config import Config
from loguru import logger


class ChatModel():
    def __init__(self, config: Config, domain: str = 'generalv3.5', model_url: str = 'wss://spark-api.xf-yun.com/v3.5/chat', stream:bool=False):
        '''
        初始化模型
        :param config: 项目配置文件
        :param domain: 调用模型
        :param llm_url: 模型地址
        :param stream: 是否启用流式调用
        '''
        self.spark = ChatSparkLLM(
            spark_api_url=model_url,
            spark_app_id=config.XF_APPID,
            spark_api_key=config.XF_APIKEY,
            spark_api_secret=config.XF_APISECRET,
            spark_llm_domain=domain,
            streaming=stream,
        )
        self.stream = stream

    def generate(self, msgs: str | List[ChatMessage]) -> str:
        '''
        批式调用
        :param msgs: 发送消息，接收字符串或列表形式的消息
        :return:
        '''
        if self.stream is True:
            raise Exception('模型初始化为流式输出，请调用generate_stream方法')

        messages = self.__trans_msgs(msgs)
        resp = self.spark.generate([messages])
        return resp.generations[0][0].text

    def generate_stream(self, msgs: str | List[ChatMessage]) -> Iterable[str]:
        '''
        流式调用
        :param msgs: 发送消息，接收字符串或列表形式的消息
        :return:
        '''
        if self.stream is False:
            raise Exception('模型初始化为流式输出，请调用generate方法')
        messages = self.__trans_msgs(msgs)
        resp_iterable = self.spark.stream(messages)
        for resp in resp_iterable:

            yield resp.content

    def __trans_msgs(self, msg: str):
        '''
        内部方法，将字符串转换为消息
        :param msgs: 字符串
        :return:
        '''
        if isinstance(msg, str):
            messages = [ChatMessage(role="user", content=msg)]
        else:
            messages = msg
        return messages


if __name__ == '__main__':
    # 初始化配置
    conf = Config()
    # 模拟问题
    question = '你好呀'
    '''
        批式调用
    '''
    logger.info('----------批式调用----------')
    model = ChatModel(conf, stream=False)
    logger.info(model.generate([ChatMessage(role="user", content=question)]))
    '''
        流式调用
    '''
    logger.info('----------流式调用----------')
    model = ChatModel(conf, stream=True)
    for r in model.generate_stream(question):
        logger.info(r)
    logger.info('done.')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @File  : VoiceModel.py
# @Author: Richard Chiming Xu
# @Date  : 2024/6/17
# @Desc  : 语音相关模型
import websocket
import datetime
import hashlib
import base64
import hmac
import json
from urllib.parse import urlencode
import time
import ssl
from wsgiref.handlers import format_date_time
from datetime import datetime
from time import mktime
import _thread as thread
import os

from dwspark.config import Config
from multiprocessing import Lock

from loguru import logger

# 接口状态
STATUS_FIRST_FRAME = 0  # 第一帧的标识
STATUS_CONTINUE_FRAME = 1  # 中间帧标识
STATUS_LAST_FRAME = 2  # 最后一帧的标识


class Text2Audio():
    def __init__(self, config: Config, model_url: str = 'wss://tts-api.xfyun.cn/v2/tts'):
        '''
        文本生成语音模型（https://www.xfyun.cn/doc/tts/online_tts/API.html）
        :param config: 项目配置文件
        :param model_url: 语音地址
        '''
        # 讯飞的api配置
        self.appid = config.XF_APPID
        self.apikey = config.XF_APIKEY
        self.apisecret = config.XF_APISECRET
        self.model_url = model_url
        # 合成语音的必要参数,具体详情可查看API文档
        self.BusinessArgs = {"aue": "lame", "auf": "audio/L16;rate=16000", "vcn": "xiaoyan", "tte": "utf8"}

    def gen_audio(self, text: str, output_path: str = './demo.mp3'):
        '''
        生成语音
        :param text: 文本
        :param output_path: 输出路径
        :return:
        '''

        websocket.enableTrace(False)
        # 创建socket地址
        wsUrl = self.__create_url()
        ws = websocket.WebSocketApp(wsUrl, on_message=self.__on_message, on_error=self.__on_error, on_close=self.__on_close)
        ws.data = {"status": 2, "text": str(base64.b64encode(text.encode('utf-8')), "UTF8")}
        ws.on_open = self.__on_open
        ws.output_path = output_path
        ws.run_forever(sslopt={"cert_reqs": ssl.CERT_NONE})
        logger.info('语音合成路径：' + ws.output_path)

    # 生成url
    def __create_url(self):
        # 生成RFC1123格式的时间戳
        now = datetime.now()
        date = format_date_time(mktime(now.timetuple()))

        # 拼接字符串
        signature_origin = "host: " + "ws-api.xfyun.cn" + "\n"
        signature_origin += "date: " + date + "\n"
        signature_origin += "GET " + "/v2/tts " + "HTTP/1.1"
        # 进行hmac-sha256进行加密
        signature_sha = hmac.new(self.apisecret.encode('utf-8'), signature_origin.encode('utf-8'),
                                 digestmod=hashlib.sha256).digest()
        signature_sha = base64.b64encode(signature_sha).decode(encoding='utf-8')

        authorization_origin = "api_key=\"%s\", algorithm=\"%s\", headers=\"%s\", signature=\"%s\"" % (
            self.apikey, "hmac-sha256", "host date request-line", signature_sha)
        authorization = base64.b64encode(authorization_origin.encode('utf-8')).decode(encoding='utf-8')
        # 将请求的鉴权参数组合为字典
        v = {
            "authorization": authorization,
            "date": date,
            "host": "ws-api.xfyun.cn"
        }
        # 拼接鉴权参数，生成url
        url = self.model_url + '?' + urlencode(v)
        return url

    # 收到websocket消息，进行出来（核心处理逻辑）
    def __on_message(self, ws, message):
        try:
            message = json.loads(message)
            code = message["code"]
            sid = message["sid"]
            audio = message["data"]["audio"]
            audio = base64.b64decode(audio)
            status = message["data"]["status"]
            if status == 2:
                ws.close()
            if code != 0:
                errMsg = message["message"]
                logger.info("sid:%s call error:%s code is:%s" % (sid, errMsg, code))
            else:

                with open(ws.output_path, 'ab') as f:
                    f.write(audio)

        except Exception as e:
            logger.info("receive msg,but parse exception:", e)

    # 收到websocket错误的处理
    def __on_error(self, ws, error):
        logger.info("### error:", error)

    # 收到websocket关闭的处理
    def __on_close(self, ws):
        logger.info("### closed ###")

    # 收到websocket连接建立的处理
    def __on_open(self, ws):
        def run(*args):
            d = {"common": {"app_id": self.appid},
                 "business": self.BusinessArgs,
                 "data": ws.data,
                 }
            d = json.dumps(d)
            ws.send(d)
            if os.path.exists('./demo.mp3'):
                os.remove('./demo.mp3')

        thread.start_new_thread(run, ())


class Audio2Text():
    def __init__(self, config: Config, model_url: str = 'wss://ws-api.xfyun.cn/v2/iat'):
        '''
        语音转文本模型（https://www.xfyun.cn/doc/asr/voicedictation/API.html）
        :param config: 项目配置文件
        :param model_url: 语音地址
        '''
        # 讯飞的api配置
        self.appid = config.XF_APPID
        self.apikey = config.XF_APIKEY
        self.apisecret = config.XF_APISECRET
        self.model_url = model_url

        # 语音识别的必要参数,具体详情可查看API文档
        self.BusinessArgs = {"domain": "iat", "language": "zh_cn", "accent": "mandarin", "vinfo": 1, "vad_eos": 10000}
        # # 语音文件路径
        # self.audio_path = ''
        # # 通用返回
        # self.resp_text = ''

    def gen_text(self, audio_path: str):
        # # 初始化属性
        # self.resp_text = ''
        # self.audio_path = audio_path
        # 创建url
        websocket.enableTrace(False)
        wsUrl = self.__create_url()
        # 调用ws
        ws = websocket.WebSocketApp(wsUrl, on_message=self.__on_message, on_error=self.__on_error, on_close=self.__on_close)
        ws.resp_text = ''
        ws.audio_path = audio_path
        ws.on_open = self.__on_open
        ws.run_forever(sslopt={"cert_reqs": ssl.CERT_NONE})
        logger.info('语音识别结果：' + ws.resp_text)
        return ws.resp_text

    # 生成url
    def __create_url(self):
        url = 'wss://ws-api.xfyun.cn/v2/iat'
        # 生成RFC1123格式的时间戳
        now = datetime.now()
        date = format_date_time(mktime(now.timetuple()))

        # 拼接字符串
        signature_origin = "host: " + "ws-api.xfyun.cn" + "\n"
        signature_origin += "date: " + date + "\n"
        signature_origin += "GET " + "/v2/iat " + "HTTP/1.1"
        # 进行hmac-sha256进行加密
        signature_sha = hmac.new(self.apisecret.encode('utf-8'), signature_origin.encode('utf-8'),
                                 digestmod=hashlib.sha256).digest()
        signature_sha = base64.b64encode(signature_sha).decode(encoding='utf-8')

        authorization_origin = "api_key=\"%s\", algorithm=\"%s\", headers=\"%s\", signature=\"%s\"" % (
            self.apikey, "hmac-sha256", "host date request-line", signature_sha)
        authorization = base64.b64encode(authorization_origin.encode('utf-8')).decode(encoding='utf-8')
        # 将请求的鉴权参数组合为字典
        v = {
            "authorization": authorization,
            "date": date,
            "host": "ws-api.xfyun.cn"
        }
        # 拼接鉴权参数，生成url
        url = url + '?' + urlencode(v)
        return url

    # 收到websocket消息的处理
    def __on_message(self, ws, message):
        try:
            code = json.loads(message)["code"]
            sid = json.loads(message)["sid"]
            if code != 0:
                errMsg = json.loads(message)["message"]
                logger.info("sid:%s call error:%s code is:%s" % (sid, errMsg, code))

            else:
                data = json.loads(message)["data"]["result"]["ws"]
                result = ""
                for i in data:
                    for w in i["cw"]:
                        result += w["w"]
                ws.resp_text += result
        except Exception as e:
            logger.info("receive msg,but parse exception:", e)

    # 收到websocket错误的处理
    def __on_error(self, ws, error):
        logger.info("### error:", error)

    # 收到websocket关闭的处理
    def __on_close(self, ws, a, b):
        logger.info("### closed ###")

    # 收到websocket连接建立的处理
    def __on_open(self, ws):
        def run(*args):
            frameSize = 8000  # 每一帧的音频大小
            intervel = 0.04  # 发送音频间隔(单位:s)
            status = STATUS_FIRST_FRAME  # 音频的状态信息，标识音频是第一帧，还是中间帧、最后一帧

            with open(ws.audio_path, "rb") as fp:
                while True:
                    buf = fp.read(frameSize)
                    # 文件结束
                    if not buf:
                        status = STATUS_LAST_FRAME
                    # 第一帧处理
                    # 发送第一帧音频，带business 参数
                    # appid 必须带上，只需第一帧发送
                    if status == STATUS_FIRST_FRAME:

                        d = {"common": {"app_id": self.appid},
                             "business": self.BusinessArgs,
                             "data": {"status": 0, "format": "audio/L16;rate=16000",
                                      "audio": str(base64.b64encode(buf), 'utf-8'),
                                      "encoding": "lame"}}
                        d = json.dumps(d)
                        ws.send(d)
                        status = STATUS_CONTINUE_FRAME
                    # 中间帧处理
                    elif status == STATUS_CONTINUE_FRAME:
                        d = {"data": {"status": 1, "format": "audio/L16;rate=16000",
                                      "audio": str(base64.b64encode(buf), 'utf-8'),
                                      "encoding": "lame"}}
                        ws.send(json.dumps(d))
                    # 最后一帧处理
                    elif status == STATUS_LAST_FRAME:
                        d = {"data": {"status": 2, "format": "audio/L16;rate=16000",
                                      "audio": str(base64.b64encode(buf), 'utf-8'),
                                      "encoding": "lame"}}
                        ws.send(json.dumps(d))
                        time.sleep(1)
                        break
                    # 模拟音频采样间隔
                    time.sleep(intervel)
            ws.close()

        thread.start_new_thread(run, ())


if __name__ == '__main__':
    lock = Lock()
    config = Config()
    text = '2023年5月，讯飞星火大模型正式发布，迅速成为千万用户获取知识、学习知识的“超级助手”，成为解放生产力、释放想象力的“超级杠杆”。2024年4月，讯飞星火V3.5春季升级长文本、长图文、长语音三大能力。一年时间内，讯飞星火从1.0到3.5，每一次迭代都是里程碑式飞跃。'
    audio_path = './demo.mp3'
    '''
        文字生成语音
    '''
    t2a = Text2Audio(config)
    # 对生成上锁，预防公有变量出现事务问题，但会降低程序并发性能。
    with lock:
        t2a.gen_audio(text, audio_path)
    '''
        语音识别文字
    '''
    a2t = Audio2Text(config)
    # 对生成上锁，预防公有变量出现事务问题，但会降低程序并发性能。
    with lock:
        audio_text = a2t.gen_text(audio_path)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @File  : ImageModel.py
# @Author: Richard Chiming Xu
# @Date  : 2024/6/17
# @Desc  : 图像模型

import ssl
import websocket
import _thread as thread
import requests
from datetime import datetime
from wsgiref.handlers import format_date_time
from time import mktime
import hashlib
import base64
import hmac
from urllib.parse import urlencode
import json
from PIL import Image
from io import BytesIO
from urllib.parse import urlparse
from dwspark.config import Config
from dwspark.utils import img_utils
from loguru import logger


class Text2Img(object):
    def __init__(self, config: Config, model_url: str = 'http://spark-api.cn-huabei-1.xf-yun.com/v2.1/tti'):
        '''
        图片生成（https://www.xfyun.cn/doc/spark/ImageGeneration.html）
        :param config: 项目配置文件
        :param model_url: 模型地址
        '''
        # 讯飞的api配置
        self.appid = config.XF_APPID
        self.apikey = config.XF_APIKEY
        self.apisecret = config.XF_APISECRET
        # url地址
        self.model_url = model_url
        self.host, self.path, self.schema = self.__parse_url(model_url)

    def gen_image(self, text: str, save_path: str) -> str:
        '''
        根据需求生成图片
        :param text: 图片描述
        :param save_path: 图片保存地址
        :return: 图片的base64数据
        '''
        # 组装请求体
        req_body = {
            "header": {"app_id": self.appid, "uid": "123456789"},
            "parameter": {"chat": {"domain": "general", "temperature": 0.5, "max_tokens": 4096}},
            "payload": {"message": {"text": [{"role": "user", "content": text}]}}
        }
        # 获取鉴权
        url = self.__create_url()
        # 发起请求
        resp_str = requests.post(url, json=req_body, headers={'content-type': "application/json"}).text
        # 保存图片
        return self.__parser_Message(resp_str, save_path)

    # 保存图片
    def __parser_Message(self, message: str, save_path: str):
        data = json.loads(message)
        code = data['header']['code']
        if code != 0:
            raise Exception(f'请求错误: {code}, {data}')
        else:
            text = data["payload"]["choices"]["text"]
            imageContent = text[0]
            # if('image' == imageContent["content_type"]):
            imageBase = imageContent["content"]
            # 解码base64数据
            img_data = base64.b64decode(imageBase)
            # 将解码后的数据转换为图片
            img = Image.open(BytesIO(img_data))
            # 保存图片到本地
            img.save(save_path)
            return imageBase

    # 生成url
    def __create_url(self, method="POST"):
        now = datetime.now()
        date = format_date_time(mktime(now.timetuple()))
        signature_origin = "host: {}\ndate: {}\n{} {} HTTP/1.1".format(self.host, date, method, self.path)
        signature_sha = hmac.new(self.apisecret.encode('utf-8'), signature_origin.encode('utf-8'),
                                 digestmod=hashlib.sha256).digest()
        signature_sha = base64.b64encode(signature_sha).decode(encoding='utf-8')
        authorization_origin = "api_key=\"%s\", algorithm=\"%s\", headers=\"%s\", signature=\"%s\"" % (
            self.apikey, "hmac-sha256", "host date request-line", signature_sha)
        authorization = base64.b64encode(authorization_origin.encode('utf-8')).decode(encoding='utf-8')
        values = {
            "host": self.host,
            "date": date,
            "authorization": authorization
        }

        return self.model_url + "?" + urlencode(values)

    # 格式化url
    def __parse_url(self, requset_url):
        stidx = requset_url.index("://")
        host = requset_url[stidx + 3:]
        schema = requset_url[:stidx + 3]
        edidx = host.index("/")
        if edidx <= 0:
            raise Exception("错误的请求地址:" + requset_url)
        path = host[edidx:]
        host = host[:edidx]
        return host, path, schema


class ImageUnderstanding(object):

    def __init__(self, config: Config, model_url: str = 'wss://spark-api.cn-huabei-1.xf-yun.com/v2.1/image'):
        '''
        图片理解（https://www.xfyun.cn/doc/spark/ImageUnderstanding.html）
        :param config: 项目配置文件
        :param model_url: 模型地址
        '''
        # 讯飞的api配置
        self.appid = config.XF_APPID
        self.apikey = config.XF_APIKEY
        self.apisecret = config.XF_APISECRET
        self.model_url = model_url
        self.host = urlparse(model_url).netloc
        self.path = urlparse(model_url).path
        # 模型答案
        self.answer = ''

    def understanding(self, text: str, img_path: str) -> str:
        # 清空答案
        self.answer = ''
        # 组装请求体
        req_body = {
            "header": {"app_id": self.appid},
            "parameter": {"chat": {"domain": "image", "temperature": 0.5, "top_k": 4, "max_tokens": 2028, "auditing": "default"}},
            "payload": {"message": {"text":[{'role': 'user', 'content': img_utils.img2base64(img_path), 'content_type': 'image'}, {'role': 'user', 'content': text}]}}
        }
        websocket.enableTrace(False)
        wsUrl = self.__create_url()
        ws = websocket.WebSocketApp(wsUrl, on_message=self.__on_message, on_error=self.__on_error, on_close=self.__on_close, on_open=self.__on_open)
        ws.appid = self.appid
        ws.req_body = req_body
        ws.question = text
        ws.run_forever(sslopt={"cert_reqs": ssl.CERT_NONE})
        return self.answer

    def __create_url(self):
        # 生成RFC1123格式的时间戳
        now = datetime.now()
        date = format_date_time(mktime(now.timetuple()))

        # 拼接字符串
        signature_origin = "host: " + self.host + "\n"
        signature_origin += "date: " + date + "\n"
        signature_origin += "GET " + self.path + " HTTP/1.1"

        # 进行hmac-sha256进行加密
        signature_sha = hmac.new(self.apisecret.encode('utf-8'), signature_origin.encode('utf-8'),
                                 digestmod=hashlib.sha256).digest()

        signature_sha_base64 = base64.b64encode(signature_sha).decode(encoding='utf-8')

        authorization_origin = f'api_key="{self.apikey}", algorithm="hmac-sha256", headers="host date request-line", signature="{signature_sha_base64}"'

        authorization = base64.b64encode(authorization_origin.encode('utf-8')).decode(encoding='utf-8')

        # 将请求的鉴权参数组合为字典
        v = {
            "authorization": authorization,
            "date": date,
            "host": self.host
        }
        # 拼接鉴权参数，生成url
        url = self.model_url + '?' + urlencode(v)
        # print(url)
        # 此处打印出建立连接时候的url,参考本demo的时候可取消上方打印的注释，比对相同参数时生成的url与自己代码生成的url是否一致
        return url

    # 收到websocket错误的处理
    def __on_error(self, ws, error):
        print("### error:", error)

    # 收到websocket关闭的处理
    def __on_close(self, ws, one, two):
        print(" ")

    # 收到websocket连接建立的处理
    def __on_open(self, ws):
        thread.start_new_thread(self.__run, (ws,))

    def __run(self, ws, *args):
        ws.send(json.dumps(ws.req_body))

    # 收到websocket消息的处理
    def __on_message(self, ws, message):
        # print(message)
        data = json.loads(message)
        code = data['header']['code']
        if code != 0:
            print(f'请求错误: {code}, {data}')
            ws.close()
        else:
            choices = data["payload"]["choices"]
            status = choices["status"]
            content = choices["text"][0]["content"]
            self.answer += content
            if status == 2:
                ws.close()




if __name__ == '__main__':
    config = Config()
    '''
        生成图片
    '''
    prompt = '一只鲸鱼在快乐游泳的卡通头像'
    t2i = Text2Img(config)
    t2i.gen_image(prompt, './demo.jpg')
    '''
        图片解释
    '''
    prompt = '请理解一下图片'
    iu = ImageUnderstanding(config)
    logger.info(iu.understanding(prompt, './demo.jpg'))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @File  : config.py
# @Author: Richard Chiming Xu
# @Date  : 2024/6/24
# @Desc  :

import os


class Config():
    def __init__(self, appid: str = None, apikey: str = None, apisecret: str = None):
        '''
        讯飞API统一的环境配置
        :param uid: uid
        :param appid: appid
        :param apikey: api key
        :param apisecret: api secret

        调用方式：
        # 加载系统环境变量xf_uid、xf_app_id、xf_app_key、xf_app_secret
        config = Config()
        # 自定义key写入
        config = Config('14****93', 'eb28b****b82', 'MWM1MzBkOD****Mzk0')
        '''
        if appid is None:
            self.XF_APPID = os.environ["SPARKAI_APP_ID"]
        else:
            self.XF_APPID = appid
        if apikey is None:
            self.XF_APIKEY = os.environ["SPARKAI_API_KEY"]
        else:
            self.XF_APIKEY = apikey
        if apisecret is None:
            self.XF_APISECRET = os.environ["SPARKAI_API_SECRET"]
        else:
            self.XF_APISECRET = apisecret



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @File  : __init__.py.py
# @Author: Richard Chiming Xu
# @Date  : 2024/6/24
# @Desc  :
from .ChatModel import ChatModel
from .AudioModel import Text2Audio, Audio2Text
from .ImageModel import Text2Img, ImageUnderstanding
from .EmbeddingModel import EmbeddingModel


__all__ = ["ChatModel", "Text2Audio", "Audio2Text", "Text2Img", "ImageUnderstanding", "EmbeddingModel"]


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @File  : img_utils.py
# @Author: Richard Chiming Xu
# @Date  : 2024/6/17
# @Desc  : 图片相关的工具类
import base64


def img2base64(img_path: str) -> str:
    '''
    读取图片成base64
    :param img_path: 图片地址
    :return:
    '''
    imagedata = open(img_path, 'rb').read()
    return str(base64.b64encode(imagedata), 'utf-8')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @File  : setup.py
# @Author: Richard Chiming Xu
# @Date  : 2024/6/24
# @Desc  :
from setuptools import setup, find_packages

with open("README.md","r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="dwspark",
    python_requires='>=3.8',
    version="2024.0.2",
    packages=find_packages(),
    install_requires=[
        "spark_ai_python",
        "loguru",
        "cffi",
        "gevent",
        "greenlet",
        "pycparser",
        "six",
        "websockets",
        "websocket-client",
        "chardet",
    ],
    author="datawhale",
    author_email="datawhale@example.com",
    description="DataWhale用于星火杯2024的适配sdk",
    long_description=long_description,
    long_description_content_type="text/markdown",
)